from typing import Optional
import os
from pathlib import Path
from dotenv import load_dotenv
import openai

class Config:
    """Configuration management for Phinity."""
    
    _instance = None
    _openai_client = None
    
    def __init__(self):
        raise RuntimeError("Use Config.get_instance()")
        
    @classmethod
    def get_instance(cls):
        if cls._instance is None:
            cls._instance = object.__new__(cls)
            cls._instance._openai_client = None
            # Load environment variables from .env file if it exists
            env_path = Path(__file__).parent.parent.parent / '.env'
            if env_path.exists():
                load_dotenv(env_path)
        return cls._instance
    
    @property
    def openai_client(self) -> Optional[openai.OpenAI]:
        return self._openai_client
    
    @classmethod
    def setup_openai(cls, api_key: str = None):
        """
        Setup OpenAI API configuration.
        
        Args:
            api_key: Optional API key. If not provided, will look for OPENAI_API_KEY environment variable.
        """
        if api_key:
            openai.api_key = api_key
        elif 'OPENAI_API_KEY' in os.environ:
            openai.api_key = os.environ['OPENAI_API_KEY']
        else:
            raise ValueError("OpenAI API key must be provided either through argument or OPENAI_API_KEY environment variable")
        
        instance = cls.get_instance()
        instance._openai_client = openai.OpenAI() 